..  Titling
    ##++::==~~--''``

Turberfield is a framework for discrete event simulations and turn-based
games.

The API may change as the project proceeds. At this early stage you should
only use the latest release; it may not be compatible with previous
versions.

If you've spotted a bug in Turberfield, please let me know so I can fix it.
If you think Turberfield lacks a feature, you can help drive development by
describing your Use Case.

In either event, please leave a message on the project's `message board`_.

Turberfield Utility library
:::::::::::::::::::::::::::

:Author: tundish
:Copyright: 2019 D Haynes
:Licence: `GNU General Public License`_

|

.. toctree::
   :maxdepth: 1
   :numbered:

   orders
   assembly
   pipes
   homogeneous
   travel
   expert

* :ref:`genindex`

.. _GNU General Public License: http://www.gnu.org/licenses/gpl.html
.. _message board: https://www.assembla.com/spaces/turberfield/messages
